====================================
README for HydraTK TestEnv extension
====================================

| TestEnv extension provides testing environment for learning automated testing together with Yoda extension.

| TestEnv provides simple CRM application with following interfaces:

* DB: interface to SQLite database
* REST: interface to REST services on web server
* SOAP: interface to SOAP services on web server